@@ -24,18 +24,14 @@
 
 #define MOD_NAME_PREFIX "OU"
 
-#define DEFAULT_MAX_BUCKET_SIZE 60
-#define DEFAULT_MAX_BTREE_SIZE 250
+
+
 
 #define ZODB_UNSIGNED_VALUE_INTS
 
-#include "_compat.h"
+#include "Python.h"
 #include "objectkeymacros.h"
 #include "intvaluemacros.h"
 
-#ifdef PY3K
 #define INITMODULE PyInit__OUBTree
-#else
-#define INITMODULE init_OUBTree
-#endif
 #include "BTreeModuleTemplate.c"
